@@ -1,4 +1,5 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
@@ -14,21 +15,18 @@ class AddUser(Request):
 
     """
 
-    def __init__(self, user_id):
+    def __init__(self, user_id: str):
+        super().__init__(path="/users/%s" % (user_id), method='put', timeout=1000, ensure_https=False)
         self.user_id = user_id
-        self.timeout = 1000
-        self.ensure_https = False
-        self.method = 'put'
-        self.path = "/users/%s" % (self.user_id)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
