@@ -1,4 +1,5 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
@@ -11,19 +12,16 @@ class DeleteAllSearchSynonyms(Request):
     """
 
     def __init__(self):
-        self.timeout = 10000
-        self.ensure_https = False
-        self.method = 'delete'
-        self.path = "/synonyms/items/" % ()
+        super().__init__(path="/synonyms/items/", method='delete', timeout=10000, ensure_https=False)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
