@@ -1,13 +1,14 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
 
 class DeleteGroup(Request):
     """
-    Deletes the group of given `groupId` from the database.
+    Deletes the group of the given `groupId` from the database.
     
-    Deleting a group will only delete assignment of items to it, not the items themselves!
+    Deleting a group will only delete the assignment of items to it, not the items themselves!
     
     Required parameters:
     
@@ -16,21 +17,18 @@ class DeleteGroup(Request):
 
     """
 
-    def __init__(self, group_id):
+    def __init__(self, group_id: str):
+        super().__init__(path="/groups/%s" % (group_id), method='delete', timeout=1000, ensure_https=False)
         self.group_id = group_id
-        self.timeout = 1000
-        self.ensure_https = False
-        self.method = 'delete'
-        self.path = "/groups/%s" % (self.group_id)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
