@@ -1,35 +1,33 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
 
 class GetItemValues(Request):
     """
-    Get all the current property values of a given item.
+    Gets all the current property values of the given item.
     
     Required parameters:
     
-    :param item_id: ID of the item properties of which are to be obtained.
+    :param item_id: ID of the item whose properties are to be obtained.
     
     
 
     """
 
-    def __init__(self, item_id):
+    def __init__(self, item_id: str):
+        super().__init__(path="/items/%s" % (item_id), method='get', timeout=1000, ensure_https=False)
         self.item_id = item_id
-        self.timeout = 1000
-        self.ensure_https = False
-        self.method = 'get'
-        self.path = "/items/%s" % (self.item_id)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
