@@ -1,4 +1,5 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
@@ -10,19 +11,16 @@ class ListSeries(Request):
     """
 
     def __init__(self):
-        self.timeout = 100000
-        self.ensure_https = False
-        self.method = 'get'
-        self.path = "/series/list/" % ()
+        super().__init__(path="/series/list/", method='get', timeout=100000, ensure_https=False)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
