@@ -1,11 +1,12 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
 
 class ListUserRatings(Request):
     """
-    List all the ratings ever submitted by a given user.
+    Lists all the ratings ever submitted by the given user.
     Required parameters:
     
     :param user_id: ID of the user whose ratings are to be listed.
@@ -13,21 +14,18 @@ class ListUserRatings(Request):
 
     """
 
-    def __init__(self, user_id):
+    def __init__(self, user_id: str):
+        super().__init__(path="/users/%s/ratings/" % (user_id), method='get', timeout=100000, ensure_https=False)
         self.user_id = user_id
-        self.timeout = 100000
-        self.ensure_https = False
-        self.method = 'get'
-        self.path = "/users/%s/ratings/" % (self.user_id)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
