@@ -1,4 +1,5 @@
 from recombee_api_client.api_requests.request import Request
+from typing import Union, List
 import uuid
 
 DEFAULT = uuid.uuid4()
@@ -19,24 +20,21 @@ class RemoveFromSeries(Request):
 
     """
 
-    def __init__(self, series_id, item_type, item_id, time):
+    def __init__(self, series_id: str, item_type: str, item_id: str, time: float):
+        super().__init__(path="/series/%s/items/" % (series_id), method='delete', timeout=1000, ensure_https=False)
         self.series_id = series_id
         self.item_type = item_type
         self.item_id = item_id
         self.time = time
-        self.timeout = 1000
-        self.ensure_https = False
-        self.method = 'delete'
-        self.path = "/series/%s/items/" % (self.series_id)
 
-    def get_body_parameters(self):
+    def get_body_parameters(self) -> dict:
         """
         Values of body parameters as a dictionary (name of parameter: value of the parameter).
         """
         p = dict()
         return p
 
-    def get_query_parameters(self):
+    def get_query_parameters(self) -> dict:
         """
         Values of query parameters as a dictionary (name of parameter: value of the parameter).
         """
